[rtems commit] psxtests/psxkey07: Account for RTEMS_TOO_MANY

Sebastian Huber sebh at rtems.org
Wed Mar 12 06:48:16 UTC 2014


Module:    rtems
Branch:    master
Commit:    fca27b727212b578d31bb99bc2bafd73b9c16ffc
Changeset: http://git.rtems.org/rtems/commit/?id=fca27b727212b578d31bb99bc2bafd73b9c16ffc

Author:    Sebastian Huber <sebastian.huber at embedded-brains.de>
Date:      Tue Mar 11 14:02:07 2014 +0100

psxtests/psxkey07: Account for RTEMS_TOO_MANY

---

 testsuites/psxtests/psxkey07/init.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/testsuites/psxtests/psxkey07/init.c b/testsuites/psxtests/psxkey07/init.c
index b2aabb7..c25227d 100644
--- a/testsuites/psxtests/psxkey07/init.c
+++ b/testsuites/psxtests/psxkey07/init.c
@@ -103,6 +103,7 @@ rtems_task Init(rtems_task_argument argument)
     );
     rtems_test_assert(
       ( rc == RTEMS_SUCCESSFUL ) || ( rc == RTEMS_UNSATISFIED )
+        || ( rc == RTEMS_TOO_MANY )
     );
 
     if ( rc == RTEMS_SUCCESSFUL ) {
@@ -111,10 +112,10 @@ rtems_task Init(rtems_task_argument argument)
     }
 
     /**
      * check if return is EAGAIN, it means RTEMS Workspace RAM
      * have been exhausted.
      */
-    if ( rc == RTEMS_UNSATISFIED ) {
+    if ( rc != RTEMS_SUCCESSFUL ) {
       pthread_mutex_unlock( &mutex1 );
       break;
     }
@@ -111,10 +112,10 @@ rtems_task Init(rtems_task_argument argument)
 
     /**
-     * check if return is EAGAIN, it means RTEMS Workspace RAM
+     * check if return is not successful, it means RTEMS Workspace RAM
      * have been exhausted.
      */




More information about the vc mailing list